@@ -18,7 +18,7 @@
 
 __author__ = """Francisco Fernandez"""
 __email__ = "fernandezfrancisco2195@gmail.com"
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 
 
 # ============================================================================
@@ -35,7 +35,7 @@ from .distances import pbc_distances  # noqa
 from .msd import MeanSquareDisplacement  # noqa
 from .rdf import RadialDistributionFunction  # noqa
 from .cn import CoordinationNumber  # noqa
-from ._cluster import EffectiveNeighbors, DBSCAN, sro  # noqa
+from .cluster import EffectiveNeighbors, DBSCAN, sro  # noqa
 
 # electrochemistry
 from .electrochemistry import (  # noqa
@@ -43,7 +43,7 @@ from .electrochemistry import (  # noqa
     formation_energy,  # noqa
     voltage,  # noqa
 )  # noqa
-from .electrochemistry.statistics import BlockAverage  # noqa
+from .statistics import BlockAverage  # noqa
 
 # io
 from .io import *  # noqa
